@@ -7,7 +7,7 @@ Automatically detects environment and configures optimal settings.
 
 import multiprocessing
 import os
-from dataclasses import dataclass, field
+from dataclasses import asdict, dataclass, field
 from pathlib import Path
 from typing import Any, Dict, List, Optional
 
@@ -94,11 +94,9 @@ class DatabaseConfig:
             test_db = Path("test_database.db")
             return f"sqlite:///{test_db.absolute()}"
         else:
-            # Production environments require explicit configuration
-            raise ValueError(
-                "Production database configuration required. "
-                "Set DATABASE_URL environment variable or provide database configuration."
-            )
+            # Production environments should have explicit configuration
+            # But for zero-config mode, default to SQLite
+            return "sqlite:///dataflow.db"
 
     def get_pool_size(self, environment: Environment) -> int:
         """Calculate optimal pool size based on environment and resources"""
@@ -201,6 +199,12 @@ class DataFlowConfig:
         self.batch_size = kwargs.get("batch_size", 1000)
         self.connection_pool_size = kwargs.get("connection_pool_size", 10)
 
+        # Schema state management settings
+        self.schema_cache_ttl = kwargs.get("schema_cache_ttl", 300)  # 5 minutes default
+        self.schema_cache_max_size = kwargs.get(
+            "schema_cache_max_size", 100
+        )  # 100 schemas default
+
         # Handle database configuration
         if "database" in kwargs and isinstance(kwargs["database"], DatabaseConfig):
             self.database = kwargs["database"]
@@ -331,7 +335,10 @@ class DataFlowConfig:
     @property
     def database_url(self):
         """Direct access to database URL"""
-        return self.database.url
+        # Return the actual URL first, but if None, calculate it based on environment
+        if self.database.url:
+            return self.database.url
+        return self.database.get_connection_url(self.environment)
 
     @database_url.setter
     def database_url(self, value: str):
@@ -428,10 +435,33 @@ class DataFlowConfig:
         """Get the current tenant context"""
         return self._tenant_context
 
+    def to_dict(self):
+        """Convert configuration to dictionary for serialization"""
+        return {
+            "environment": (
+                self.environment.value.lower()
+                if hasattr(self.environment, "value")
+                else str(self.environment).lower()
+            ),
+            "database": asdict(self.database),
+            "monitoring": asdict(self.monitoring),
+            "security": asdict(self.security),
+            "debug": self.debug,
+            "auto_commit": self.auto_commit,
+            "batch_size": self.batch_size,
+            "connection_pool_size": self.connection_pool_size,
+            "schema_cache_ttl": self.schema_cache_ttl,
+            "schema_cache_max_size": self.schema_cache_max_size,
+        }
+
     @property
     def monitoring(self):
-        """Direct access to monitoring - returns boolean for backward compatibility"""
-        return self._monitoring_bool if hasattr(self, "_monitoring_bool") else False
+        """Direct access to monitoring - returns MonitoringConfig object for structured access"""
+        return (
+            self._monitoring_config
+            if hasattr(self, "_monitoring_config")
+            else MonitoringConfig()
+        )
 
     @monitoring.setter
     def monitoring(self, value):
@@ -478,30 +508,6 @@ class DataFlowConfig:
         """Set encryption enabled"""
         self._encryption_enabled = value
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Convert configuration to dictionary"""
-        return {
-            "environment": (
-                self.environment.value
-                if hasattr(self.environment, "value")
-                else str(self.environment)
-            ),
-            "debug": self.debug,
-            "auto_commit": self.auto_commit,
-            "batch_size": self.batch_size,
-            "connection_pool_size": self.connection_pool_size,
-            "database_url": self.database_url,
-            "pool_size": self.pool_size,
-            "pool_max_overflow": self.pool_max_overflow,
-            "pool_recycle": self.pool_recycle,
-            "multi_tenant": self.multi_tenant,
-            "monitoring": self._monitoring_config.enabled,
-            "slow_query_threshold": self.slow_query_threshold,
-            "cache_enabled": self.cache_enabled,
-            "cache_ttl": self.cache_ttl,
-            "audit_logging": self.audit_logging,
-        }
-
     @classmethod
     def from_env(cls) -> "DataFlowConfig":
         """Create configuration from environment variables"""
@@ -510,6 +516,12 @@ class DataFlowConfig:
         # Database configuration from env
         if db_url := os.getenv("DATABASE_URL"):
             config.database.url = db_url
+            config.database.database_url = db_url
+        else:
+            # Default to SQLite for zero-config mode
+            default_url = "sqlite:///dataflow.db"
+            config.database.url = default_url
+            config.database.database_url = default_url
 
         # Pool settings from env
         if pool_size := os.getenv("DATAFLOW_POOL_SIZE", os.getenv("DB_POOL_SIZE")):
@@ -563,6 +575,13 @@ class DataFlowConfig:
                     "Set DATABASE_URL or provide database configuration."
                 )
 
+            # Check for SQLite in production
+            db_url = self.database.get_connection_url(self.environment)
+            if db_url and "sqlite" in db_url.lower():
+                issues.append(
+                    "SQLite database is not recommended for production environments"
+                )
+
         # Validation for pool settings
         if self.database.pool_size is not None:
             if self.database.pool_size < 1:
