@@ -149,7 +149,8 @@ class BulkDeleteNode(SmartNodeConnectionMixin, AsyncNode):
             soft_delete = validated_inputs.get("soft_delete", False)
 
             # Validate inputs
-            if not filter_conditions and not ids:
+            # Use key existence check instead of truthiness to allow empty filter {}
+            if "filter" not in validated_inputs and not ids:
                 raise NodeValidationError(
                     "Either filter conditions or ids must be provided"
                 )
